use actix_web::{web, HttpResponse, Responder};
use garde::Validate;
use sqlx::PgPool;

use crate::{
    endpoints::{
        clothing::{NewOrEditClothingForm, ReadClothingPartialTemplate},
        IdPath,
    },
    models::{Clothing, Role, User},
    utils::{ApplicationError, TemplateResponse},
};

#[actix_web::post("/clothing/{id}")]
pub async fn post(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    path: web::Path<IdPath>,
    form: web::Form<NewOrEditClothingForm>,
) -> Result<impl Responder, ApplicationError> {
    if user.role != Role::Admin {
        return Err(ApplicationError::Unauthorized);
    }

    let Some(mut clothing) = Clothing::read(pool.get_ref(), path.id).await? else {
        return Ok(HttpResponse::NotFound().finish());
    };

    if let Err(e) = form.validate() {
        return Ok(HttpResponse::UnprocessableEntity().body(e.to_string()));
    };

    clothing.name = form.name.to_string();

    Clothing::update(pool.get_ref(), clothing.id, &clothing.name).await?;

    let template = ReadClothingPartialTemplate { c: clothing };

    Ok(template.to_response()?)
}
